hipcc uses -stdlib=stdlibc++ by default.
hipcc switches to -stdlib=libc++ if user requests it. hack to disable LDG.
Этот коммит содержится в:
@@ -21,9 +21,10 @@ THE SOFTWARE.
|
||||
#define HIP_LDG_H
|
||||
|
||||
#if __HCC__
|
||||
#if defined (USE_LDG)
|
||||
#include"hip_vector_types.h"
|
||||
#include"host_defines.h"
|
||||
#if __hcc_workweek__ >= 16164
|
||||
#if __hcc_workweek__ >= 16164
|
||||
#include"hip/hip_vector_types.h"
|
||||
#include"hip/hcc_detail/host_defines.h"
|
||||
|
||||
@@ -101,5 +102,7 @@ __device__ double4 __ldg(const double4* );
|
||||
|
||||
#endif // __HCC__
|
||||
|
||||
#endif
|
||||
|
||||
#endif // HIP_LDG_H
|
||||
|
||||
|
||||
@@ -45,11 +45,9 @@ THE SOFTWARE.
|
||||
//---
|
||||
// Remainder of this file only compiles with HCC
|
||||
#ifdef __HCC__
|
||||
//#if __cplusplus
|
||||
//#include <hc.hpp>
|
||||
//#endif
|
||||
#include <grid_launch.h>
|
||||
#include <kalmar_defines.h>
|
||||
|
||||
extern int HIP_TRACE_API;
|
||||
|
||||
//TODO-HCC-GL - change this to typedef.
|
||||
@@ -112,6 +110,7 @@ extern int HIP_TRACE_API;
|
||||
#define __HCC_C__
|
||||
#endif
|
||||
|
||||
#ifdef DISABLED_MATH_FUNC // TODO - remove this flag.
|
||||
__device__ float acosf(float x);
|
||||
__device__ float acoshf(float x);
|
||||
__device__ float asinf(float x);
|
||||
@@ -445,7 +444,7 @@ __device__ float __dsqrt_rd(double x);
|
||||
__device__ float __dsqrt_rn(double x);
|
||||
__device__ float __dsqrt_ru(double x);
|
||||
__device__ float __dsqrt_rz(double x);
|
||||
#endif
|
||||
#endif /* DISABLED_MATH_FUNC*/
|
||||
/**
|
||||
* Kernel launching
|
||||
*/
|
||||
@@ -575,3 +574,4 @@ do {\
|
||||
|
||||
|
||||
#endif
|
||||
#endif
|
||||
|
||||
Ссылка в новой задаче
Block a user